@@ -8,7 +8,7 @@
 #             Handles layman actions.
 #
 # Copyright:
-#             (c) 2005 - 2006 Gunnar Wrobel
+#             (c) 2005 - 2008 Gunnar Wrobel
 #             Distributed under the terms of the GNU General Public License v2
 #
 # Author(s):
@@ -90,13 +90,16 @@ class Sync:
 
         self.rdb = RemoteDB(config)
 
+        self.quiet = config['quiet']
+
         self.selection = config['sync']
 
 	if config['sync_all'] or 'ALL' in self.selection:
 	    self.selection = self.db.overlays.keys()
 
         enc = sys.getfilesystemencoding()
-        self.selection = [i.decode(enc) for i in self.selection]
+        if enc:
+            self.selection = [i.decode(enc) for i in self.selection]
 
     def run(self):
         '''Synchronize the overlays.'''
@@ -117,7 +120,7 @@ class Sync:
                     'dding the overlay!')
 
             try:
-                self.db.sync(i)
+                self.db.sync(i, self.quiet)
                 success.append('Successfully synchronized overlay "' + i + '".')
             except Exception, error:
                 warnings.append(
@@ -154,10 +157,13 @@ class Add:
 
         self.rdb = RemoteDB(config)
 
+        self.quiet = config['quiet']
+
         self.selection = config['add']
 
         enc = sys.getfilesystemencoding()
-        self.selection = [i.decode(enc) for i in self.selection]
+        if enc:
+            self.selection = [i.decode(enc) for i in self.selection]
 
         if 'ALL' in self.selection:
             self.selection = self.rdb.overlays.keys()
@@ -176,7 +182,7 @@ class Add:
 
             if overlay:
                 try:
-                    self.db.add(overlay)
+                    self.db.add(overlay, self.quiet)
                     OUT.info('Successfully added overlay "' + i + '".', 2)
                 except Exception, error:
                     OUT.warn('Failed to add overlay "' + i + '".\nError was: '
@@ -204,7 +210,8 @@ class Delete:
         self.selection = config['delete']
 
         enc = sys.getfilesystemencoding()
-        self.selection = [i.decode(enc) for i in self.selection]
+        if enc:
+            self.selection = [i.decode(enc) for i in self.selection]
 
         if 'ALL' in self.selection:
             self.selection = self.db.overlays.keys()
@@ -281,7 +288,8 @@ class Info:
         self.selection = config['info']
 
         enc = sys.getfilesystemencoding()
-        self.selection = [i.decode(enc) for i in self.selection]
+        if enc:
+            self.selection = [i.decode(enc) for i in self.selection]
 
         if 'ALL' in self.selection:
             self.selection = self.rdb.overlays.keys()
