@@ -8,7 +8,7 @@
 #             Handles git overlays
 #
 # Copyright:
-#             (c) 2005 - 2006 Gunnar Wrobel, Stefan Schweizer
+#             (c) 2005 - 2008 Gunnar Wrobel, Stefan Schweizer
 #             Distributed under the terms of the GNU General Public License v2
 #
 # Author(s):
@@ -40,21 +40,35 @@ class GitOverlay(Overlay):
 
     binary_command  = '/usr/bin/git'
 
-    def add(self, base):
+    def add(self, base, quiet = False):
         '''Add overlay.'''
 
         self.supported()
 
-        return self.cmd(self.binary_command + ' clone "' + self.src + '/" "'
-                        + path([base, self.name]) + '"')
+        if quiet:
+            quiet_option = '-q '
+        else:
+            quiet_option = ''
+ 
+        # http:// should get trailing slash, other protocols shouldn't
+        slash = ''
+        if self.src.split(':')[0] == 'http':
+            slash = '/'
+        return self.cmd(self.binary_command + ' clone ' + quiet_option + '"' + self.src + slash
+                        + '" "' + path([base, self.name]) + '"')
 
-    def sync(self, base):
+    def sync(self, base, quiet = False):
         '''Sync overlay.'''
 
         self.supported()
 
+        if quiet:
+            quiet_option = '-q '
+        else:
+            quiet_option = ''
+ 
         return self.cmd('cd "' + path([base, self.name]) + '" && '
-                        + self.binary_command + ' pull')
+                        + self.binary_command + ' pull' + quiet_option)
 
     def supported(self):
         '''Overlay type supported?'''
