@@ -8,7 +8,7 @@
 #             Base class for the different overlay types.
 #
 # Copyright:
-#             (c) 2005 - 2006 Gunnar Wrobel
+#             (c) 2005 - 2008 Gunnar Wrobel
 #             Distributed under the terms of the GNU General Public License v2
 #
 # Author(s):
@@ -24,7 +24,7 @@ __version__ = "$Id: overlay.py 273 2006-12-30 15:54:50Z wrobel $"
 #
 #-------------------------------------------------------------------------------
 
-import sys, types, re, os, os.path, shutil, popen2
+import sys, types, re, os, os.path, shutil, subprocess
 
 from   layman.utils             import node_to_dict, dict_to_node, path
 
@@ -123,7 +123,7 @@ class Overlay:
 
         return dict_to_node(self.data, document, 'overlay')
 
-    def add(self, base):
+    def add(self, base, quiet = False):
         '''Add the overlay.'''
 
         mdir = path([base, self.name])
@@ -134,7 +134,7 @@ class Overlay:
 
         os.makedirs(mdir)
 
-    def sync(self, base):
+    def sync(self, base, quiet = False):
         '''Sync the overlay.'''
         pass
 
@@ -154,18 +154,16 @@ class Overlay:
         OUT.info('Running command "' + command + '"...', 2)
 
         if hasattr(sys.stdout,'encoding'):
-            command = command.encode(sys.stdout.encoding or 
-                                     sys.getfilesystemencoding())
+            enc = sys.stdout.encoding or sys.getfilesystemencoding()
+            if enc:
+                command = command.encode(enc)
 
         if not self.quiet:
             return os.system(command)
         else:
-            cmd = popen2.Popen4(command)
-            cmd.fromchild.readlines()
+            cmd = subprocess.Popen([command], stdout=subprocess.PIPE,
+                                   stderr=subprocess.PIPE, close_fds=True)
             result = cmd.wait()
-            cmd.fromchild.readlines()
-            cmd.fromchild.close()
-            cmd.tochild.close()
             return result
 
     def __str__(self):
